@@ -1,9 +1,8 @@
-use unicode_segmentation::UnicodeSegmentation;
-
 use crate::{
     error::{InquireError, InquireResult},
     formatter::{BoolFormatter, DEFAULT_BOOL_FORMATTER},
-    key::{Key, KeyModifiers},
+    input::Input,
+    key::Key,
     parser::{BoolParser, DEFAULT_BOOL_PARSER},
     renderer::Renderer,
     terminal::Terminal,
@@ -25,7 +24,7 @@ pub struct Confirm<'a> {
     pub formatter: BoolFormatter<'a>,
 
     /// Function that parses the user input and returns the result
-    pub parser: BoolParser,
+    pub parser: BoolParser<'a>,
 
     /// Function that formats the default value to be presented to the user
     pub default_value_formatter: BoolFormatter<'a>,
@@ -36,13 +35,13 @@ impl<'a> Confirm<'a> {
     pub const DEFAULT_FORMATTER: BoolFormatter<'a> = DEFAULT_BOOL_FORMATTER;
     /// Default parser, matches ["y"] and ["yes"] to [true], ["n"] and ["no"]
     /// to [false], and an [Err] otherwise.
-    pub const DEFAULT_PARSER: BoolParser = DEFAULT_BOOL_PARSER;
+    pub const DEFAULT_PARSER: BoolParser<'a> = DEFAULT_BOOL_PARSER;
 
     /// Default formatter for default values, mapping [true] to ["Y/n"] and
     /// [false] to ["y/N"]
-    pub const DEFAULT_DEFAULT_VALUE_FORMATTER: BoolFormatter<'a> = |ans| match ans {
-        true => "Y/n",
-        false => "y/N",
+    pub const DEFAULT_DEFAULT_VALUE_FORMATTER: BoolFormatter<'a> = &|ans| match ans {
+        true => String::from("Y/n"),
+        false => String::from("y/N"),
     };
 
     /// Creates a [Confirm] with the provided message and default configuration values.
@@ -76,7 +75,7 @@ impl<'a> Confirm<'a> {
     }
 
     /// Sets the parser
-    pub fn with_parser(mut self, parser: BoolParser) -> Self {
+    pub fn with_parser(mut self, parser: BoolParser<'a>) -> Self {
         self.parser = parser;
         self
     }
@@ -111,9 +110,9 @@ struct ConfirmPrompt<'a> {
     error: Option<String>,
     help_message: Option<&'a str>,
     default: Option<bool>,
-    content: String,
+    input: Input,
     formatter: BoolFormatter<'a>,
-    parser: BoolParser,
+    parser: BoolParser<'a>,
     default_value_formatter: BoolFormatter<'a>,
 }
 
@@ -127,31 +126,23 @@ impl<'a> From<Confirm<'a>> for ConfirmPrompt<'a> {
             formatter: co.formatter,
             parser: co.parser,
             default_value_formatter: co.default_value_formatter,
-            content: String::new(),
+            input: Input::new(),
         }
     }
 }
 
 impl<'a> ConfirmPrompt<'a> {
     fn on_change(&mut self, key: Key) {
-        match key {
-            Key::Backspace => {
-                let len = self.content[..].graphemes(true).count();
-                let new_len = len.saturating_sub(1);
-                self.content = self.content[..].graphemes(true).take(new_len).collect();
-            }
-            Key::Char(c, KeyModifiers::NONE) => self.content.push(c),
-            _ => {}
-        }
+        self.input.handle_key(key);
     }
 
     fn get_final_answer(&self) -> Result<bool, String> {
         match self.default {
-            Some(val) if self.content.is_empty() => return Ok(val),
+            Some(val) if self.input.content().is_empty() => return Ok(val),
             _ => {}
         }
 
-        (self.parser)(&self.content)
+        (self.parser)(self.input.content())
     }
 
     fn render(&mut self, renderer: &mut Renderer) -> InquireResult<()> {
@@ -165,7 +156,7 @@ impl<'a> ConfirmPrompt<'a> {
 
         let default_message = self.default.map(self.default_value_formatter);
 
-        renderer.print_prompt(&prompt, default_message, Some(&self.content))?;
+        renderer.print_prompt_input(&prompt, default_message.as_deref(), &self.input)?;
 
         if let Some(message) = self.help_message {
             renderer.print_help(message)?;
@@ -193,7 +184,7 @@ impl<'a> ConfirmPrompt<'a> {
                     }
                     Err(message) => {
                         self.error = Some(message);
-                        self.content.clear();
+                        self.input.clear();
                     }
                 },
                 key => self.on_change(key),
