@@ -1,10 +1,17 @@
 mod confirm;
+#[cfg(feature = "date")]
+mod dateselect;
+
 mod multiselect;
 mod password;
 mod select;
 mod text;
 
 pub use confirm::Confirm;
+
+#[cfg(feature = "date")]
+pub use dateselect::DateSelect;
+
 pub use multiselect::MultiSelect;
 pub use password::Password;
 pub use select::Select;
