@@ -1,10 +1,9 @@
-use unicode_segmentation::UnicodeSegmentation;
-
 use crate::{
     answer::OptionAnswer,
     config::{self, Suggester},
     error::{InquireError, InquireResult},
     formatter::{StringFormatter, DEFAULT_STRING_FORMATTER},
+    input::Input,
     key::{Key, KeyModifiers},
     renderer::Renderer,
     terminal::Terminal,
@@ -27,7 +26,7 @@ pub struct Text<'a> {
     pub help_message: Option<&'a str>,
 
     /// Function that formats the user input and presents it to the user as the final rendering of the prompt.
-    pub formatter: StringFormatter,
+    pub formatter: StringFormatter<'a>,
 
     /// Collection of validators to apply to the user input.
     /// Validation errors are displayed to the user one line above the prompt.
@@ -37,14 +36,14 @@ pub struct Text<'a> {
     pub page_size: usize,
 
     /// Function that provides a list of suggestions to the user based on the current input.
-    pub suggester: Option<Suggester>,
+    pub suggester: Option<Suggester<'a>>,
 }
 
 impl<'a> Text<'a> {
     /// Default page size, equal to the global default page size [config::DEFAULT_PAGE_SIZE]
     pub const DEFAULT_PAGE_SIZE: usize = config::DEFAULT_PAGE_SIZE;
     /// Default formatter.
-    pub const DEFAULT_FORMATTER: StringFormatter = DEFAULT_STRING_FORMATTER;
+    pub const DEFAULT_FORMATTER: StringFormatter<'a> = DEFAULT_STRING_FORMATTER;
     /// Default collection of validators.
     pub const DEFAULT_VALIDATORS: Vec<StringValidator<'a>> = Vec::new();
     /// Default help message.
@@ -76,13 +75,13 @@ impl<'a> Text<'a> {
     }
 
     /// Sets the suggester.
-    pub fn with_suggester(mut self, suggester: Suggester) -> Self {
+    pub fn with_suggester(mut self, suggester: Suggester<'a>) -> Self {
         self.suggester = Some(suggester);
         self
     }
 
     /// Sets the formatter
-    pub fn with_formatter(mut self, formatter: StringFormatter) -> Self {
+    pub fn with_formatter(mut self, formatter: StringFormatter<'a>) -> Self {
         self.formatter = formatter;
         self
     }
@@ -134,11 +133,11 @@ struct TextPrompt<'a> {
     message: &'a str,
     default: Option<&'a str>,
     help_message: Option<&'a str>,
-    content: String,
-    formatter: StringFormatter,
+    input: Input,
+    formatter: StringFormatter<'a>,
     validators: Vec<StringValidator<'a>>,
     error: Option<String>,
-    suggester: Option<Suggester>,
+    suggester: Option<Suggester<'a>>,
     suggested_options: Vec<String>,
     cursor_index: usize,
     page_size: usize,
@@ -153,7 +152,7 @@ impl<'a> From<Text<'a>> for TextPrompt<'a> {
             formatter: so.formatter,
             validators: so.validators,
             suggester: so.suggester,
-            content: String::new(),
+            input: Input::new(),
             error: None,
             cursor_index: 0,
             page_size: so.page_size,
@@ -175,7 +174,7 @@ impl<'a> TextPrompt<'a> {
     fn update_suggestions(&mut self) {
         match self.suggester {
             Some(suggester) => {
-                self.suggested_options = suggester(&self.content);
+                self.suggested_options = suggester(self.input.content());
                 if self.suggested_options.len() > 0
                     && self.suggested_options.len() <= self.cursor_index
                 {
@@ -186,57 +185,50 @@ impl<'a> TextPrompt<'a> {
         }
     }
 
-    fn move_cursor_up(&mut self) {
+    fn move_cursor_up(&mut self) -> bool {
         self.cursor_index = self
             .cursor_index
             .checked_sub(1)
             .or(self.suggested_options.len().checked_sub(1))
             .unwrap_or_else(|| 0);
+        false
     }
 
-    fn move_cursor_down(&mut self) {
+    fn move_cursor_down(&mut self) -> bool {
         self.cursor_index = self.cursor_index.saturating_add(1);
         if self.cursor_index >= self.suggested_options.len() {
             self.cursor_index = 0;
         }
+        false
     }
 
     fn on_change(&mut self, key: Key) {
-        let mut dirty = false;
-
-        match key {
+        let dirty = match key {
             Key::Tab => self.use_select_option(),
-            Key::Backspace => {
-                let len = self.content[..].graphemes(true).count();
-                let new_len = len.saturating_sub(1);
-                self.content = self.content[..].graphemes(true).take(new_len).collect();
-                dirty = true;
-            }
             Key::Up(KeyModifiers::NONE) => self.move_cursor_up(),
             Key::Down(KeyModifiers::NONE) => self.move_cursor_down(),
-            Key::Char(c, KeyModifiers::NONE) => {
-                self.content.push(c);
-                dirty = true;
-            }
-            _ => {}
-        }
+            key => self.input.handle_key(key),
+        };
 
         if dirty {
             self.update_suggestions();
         }
     }
 
-    fn use_select_option(&mut self) {
+    fn use_select_option(&mut self) -> bool {
         let selected_suggestion = self.suggested_options.get(self.cursor_index);
 
         if let Some(ans) = selected_suggestion {
-            self.content = ans.clone();
+            self.input = self.input.clone().with_content(ans);
             self.update_suggestions();
+            true
+        } else {
+            false
         }
     }
 
     fn get_final_answer(&self) -> Result<String, String> {
-        if self.content.is_empty() {
+        if self.input.content().is_empty() {
             match self.default {
                 Some(val) => return Ok(val.to_string()),
                 None => {}
@@ -244,13 +236,13 @@ impl<'a> TextPrompt<'a> {
         }
 
         for validator in &self.validators {
-            match validator(&self.content) {
+            match validator(self.input.content()) {
                 Ok(_) => {}
                 Err(err) => return Err(err),
             }
         }
 
-        Ok(self.content.clone())
+        Ok(self.input.content().into())
     }
 
     fn render(&mut self, renderer: &mut Renderer) -> InquireResult<()> {
@@ -262,7 +254,7 @@ impl<'a> TextPrompt<'a> {
             renderer.print_error_message(err)?;
         }
 
-        renderer.print_prompt(&prompt, self.default, Some(&self.content))?;
+        renderer.print_prompt_input(&prompt, self.default, &self.input)?;
 
         let choices = self
             .suggested_options
@@ -308,7 +300,7 @@ impl<'a> TextPrompt<'a> {
             }
         }
 
-        renderer.cleanup(&self.message, (self.formatter)(&final_answer))?;
+        renderer.cleanup(&self.message, &(self.formatter)(&final_answer))?;
 
         Ok(final_answer)
     }
